@@ -3,17 +3,20 @@ package Net::DNS::Resolver::Unbound;
 use strict;
 use warnings;
 use integer;
-use Net::DNS;
 
-use constant OS_SPEC => defined eval "require Net::DNS::Resolver::$^O";	## no critic
-use constant OS_CONF => join '::', 'Net::DNS::Resolver', OS_SPEC ? $^O : 'UNIX';
+use Net::DNS;
 use base qw(Net::DNS::Resolver::Base DynaLoader);
-use base OS_CONF;
+
+use constant OS_SPEC => "Net::DNS::Resolver::$^O";
+use constant OS_UNIX => "Net::DNS::Resolver::UNIX";
+use constant OS_CONF => grep eval "require $_", OS_SPEC, OS_UNIX;	## no critic
+use base (OS_CONF)[0];			## backward compatibility only
+
 
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.31_01';
+	$VERSION = '1.31_02';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -101,6 +104,7 @@ sub import {
 	my ( $class, @argument ) = @_;
 	my $register = grep {/^-register$/i} @argument;
 	@Net::DNS::Resolver::ISA = $class if $register;
+	return;
 }
 
 
@@ -220,7 +224,7 @@ sub nameservers {
 	return;
 }
 
-sub nameserver { &nameservers; }
+sub nameserver { return &nameservers }
 
 
 =head2 search, query, send, bgsend, bgbusy, bgread
